==> aeon-0.1.0.tar.gz: aeon-0.1.0/docs/examples.md <==
# Examples

## Forecasting

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/img/forecasting2.png
:link: /examples/01_forecasting.ipynb
:link-type: ref
:text-align: center

Forecasting with sktime

:::

:::{grid-item-card}
:link: /examples/01a_forecasting_sklearn.ipynb
:link-type: ref
:text-align: center

Forecasting with sktime - appendix: forecasting, supervised regression, and pitfalls in confusing the two

:::

:::{grid-item-card}
:link: /examples/01b_forecasting_proba.ipynb
:link-type: ref
:text-align: center

Probabilistic Forecasting with sktime

:::

:::{grid-item-card}
:link: /examples/01c_forecasting_hierarchical_global.ipynb
:link-type: ref
:text-align: center

Hierarchical, Global, and Panel Forecasting with sktime

:::

:::{grid-item-card}
:link: /examples/window_splitters.ipynb
:link-type: ref
:text-align: center

Window Splitters in Sktime

:::

::::

## Classification

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/img/tsc.png
:link: /examples/classification/classification.ipynb
:link-type: ref
:text-align: center

Time Series Classification with aeon

:::

:::{grid-item-card}
:link: /examples/classification/convolution_based.ipynb
:link-type: ref
:text-align: center

Convolution based time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/deep_learning.ipynb
:link-type: ref
:text-align: center

Deep learning based time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/dictionary_based.ipynb
:link-type: ref
:text-align: center

Dictionary based time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/distance_based.ipynb
:link-type: ref
:text-align: center

Distance based time series classification in sktime

:::

:::{grid-item-card}
:link: /examples/classification/feature_based.ipynb
:link-type: ref
:text-align: center

Feature based time series classification in sktime

:::

:::{grid-item-card}
:link: /examples/classification/hybrid.ipynb
:link-type: ref
:text-align: center

Hybrid time series classification in sktime

:::

:::{grid-item-card}
:link: /examples/classification/interval_based.ipynb
:link-type: ref
:text-align: center

Interval based time series classification in sktime

:::

:::{grid-item-card}
:link: /examples/classification/shapelet_based.ipynb
:link-type: ref
:text-align: center

Shapelet based time series classification in sktime

:::

:::{grid-item-card}
:link: /examples/classification/early_classification.ipynb
:link-type: ref
:text-align: center

Early time series classification with sktime

:::

:::{grid-item-card}
:link: /examples/classification/channel_selection.ipynb
:link-type: ref
:text-align: center

Channel Selection in Multivariate Time Series Classification

:::

::::

(examples-regression)=
## Regression

To come!

(examples-clustering)=
## Clustering

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/partition_based_clustering.ipynb
:link-type: ref
:text-align: center

Partition based time series clustering in sktime

:::

::::

## Annotation

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/segmentation_with_clasp.ipynb
:link-type: ref
:text-align: center

Time Series Segmentation with sktime and ClaSP

:::

::::

(examples-transformation)=
## Transformation

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/catch22.ipynb
:link-type: ref
:text-align: center

The Canonical Time-series Characteristics (catch22) transform

:::

:::{grid-item-card}
:link: /examples/feature_extraction_with_tsfresh.ipynb
:link-type: ref
:text-align: center

Feature extraction with tsfresh transformer

:::

:::{grid-item-card}
:link: /examples/hidalgo_segmentation.ipynb
:link-type: ref
:text-align: center

Hidalgo segmentation

:::

:::{grid-item-card}
:link: /examples/interpolation.ipynb
:link-type: ref
:text-align: center

Time series interpolating with sktime

:::

:::{grid-item-card}
:link: /examples/minirocket.ipynb
:link-type: ref
:text-align: center

MiniRocket

:::

:::{grid-item-card}
:link: /examples/plateau_finder.ipynb
:link-type: ref
:text-align: center

Demo of the PlateauFinder transformer

:::

:::{grid-item-card}
:link: /examples/rocket.ipynb
:link-type: ref
:text-align: center

Demo of ROCKET transform

:::

:::{grid-item-card}
:link: /examples/signature_method.ipynb
:link-type: ref
:text-align: center

The Signature Method with Sktime

:::

:::{grid-item-card}
:link: /examples/theta_transform.ipynb
:link-type: ref
:text-align: center

Theta Lines transformer

:::

::::

## Data

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/AA_datatypes_and_datasets.ipynb
:link-type: ref
:text-align: center

In-memory data representations and data loading

:::

:::{grid-item-card}
:link: /examples/loading_data.ipynb
:link-type: ref
:text-align: center

Loading data into sktime

:::

::::

## Other

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/04_benchmarking.ipynb
:link-type: ref
:text-align: center

Benchmarking with sktime

:::

:::{grid-item-card}
:link: /examples/distances.ipynb
:link-type: ref
:text-align: center

Distances

:::

:::{grid-item-card}
:link: /examples/mlflow.ipynb
:link-type: ref
:text-align: center

MLflow

:::

::::

==> aeon-0.2.0.tar.gz: aeon-0.2.0/docs/examples.md <==
# Examples

## Forecasting

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/img/forecasting2.png
:link: /examples/01_forecasting.ipynb
:link-type: ref
:text-align: center

Forecasting with aeon

:::

:::{grid-item-card}
:link: /examples/01a_forecasting_sklearn.ipynb
:link-type: ref
:text-align: center

Forecasting with aeon - appendix: forecasting, supervised regression, and pitfalls in confusing the two

:::

:::{grid-item-card}
:link: /examples/01b_forecasting_proba.ipynb
:link-type: ref
:text-align: center

Probabilistic Forecasting with aeon

:::

:::{grid-item-card}
:link: /examples/01c_forecasting_hierarchical_global.ipynb
:link-type: ref
:text-align: center

Hierarchical, Global, and Panel Forecasting with aeon

:::

:::{grid-item-card}
:link: /examples/window_splitters.ipynb
:link-type: ref
:text-align: center

Window Splitters in aeon

:::

::::

## Classification

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/img/tsc.png
:link: /examples/classification/classification.ipynb
:link-type: ref
:text-align: center

Time Series Classification with aeon

:::

:::{grid-item-card}
:link: /examples/classification/convolution_based.ipynb
:link-type: ref
:text-align: center

Convolution based time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/deep_learning.ipynb
:link-type: ref
:text-align: center

Deep learning based time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/dictionary_based.ipynb
:link-type: ref
:text-align: center

Dictionary based time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/distance_based.ipynb
:link-type: ref
:text-align: center

Distance based time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/feature_based.ipynb
:link-type: ref
:text-align: center

Feature based time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/hybrid.ipynb
:link-type: ref
:text-align: center

Hybrid time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/interval_based.ipynb
:link-type: ref
:text-align: center

Interval based time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/shapelet_based.ipynb
:link-type: ref
:text-align: center

Shapelet based time series classification in aeon

:::

:::{grid-item-card}
:link: /examples/classification/early_classification.ipynb
:link-type: ref
:text-align: center

Early time series classification with aeon

:::

:::{grid-item-card}
:link: /examples/classification/channel_selection.ipynb
:link-type: ref
:text-align: center

Channel Selection in Multivariate Time Series Classification

:::

::::

(examples-regression)=
## Regression

To come!

(examples-clustering)=
## Clustering

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/partition_based_clustering.ipynb
:link-type: ref
:text-align: center

Partition based time series clustering in aeon

:::

::::

## Annotation

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/segmentation_with_clasp.ipynb
:link-type: ref
:text-align: center

Time Series Segmentation with aeon and ClaSP

:::

::::

(examples-transformation)=
## Transformation

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/catch22.ipynb
:link-type: ref
:text-align: center

The Canonical Time-series Characteristics (catch22) transform

:::

:::{grid-item-card}
:link: /examples/feature_extraction_with_tsfresh.ipynb
:link-type: ref
:text-align: center

Feature extraction with tsfresh transformer

:::

:::{grid-item-card}
:link: /examples/hidalgo_segmentation.ipynb
:link-type: ref
:text-align: center

Hidalgo segmentation

:::

:::{grid-item-card}
:link: /examples/interpolation.ipynb
:link-type: ref
:text-align: center

Time series interpolating with aeon

:::

:::{grid-item-card}
:link: /examples/minirocket.ipynb
:link-type: ref
:text-align: center

MiniRocket

:::

:::{grid-item-card}
:link: /examples/plateau_finder.ipynb
:link-type: ref
:text-align: center

Demo of the PlateauFinder transformer

:::

:::{grid-item-card}
:link: /examples/rocket.ipynb
:link-type: ref
:text-align: center

Demo of ROCKET transform

:::

:::{grid-item-card}
:link: /examples/signature_method.ipynb
:link-type: ref
:text-align: center

The Signature Method with aeon

:::

:::{grid-item-card}
:link: /examples/theta_transform.ipynb
:link-type: ref
:text-align: center

Theta Lines transformer

:::

::::

## Data

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/AA_datatypes_and_datasets.ipynb
:link-type: ref
:text-align: center

In-memory data representations and data loading

:::

:::{grid-item-card}
:link: /examples/loading_data.ipynb
:link-type: ref
:text-align: center

Loading data into aeon

:::

::::

## Other

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/04_benchmarking.ipynb
:link-type: ref
:text-align: center

Benchmarking with aeon

:::

:::{grid-item-card}
:link: /examples/distances.ipynb
:link-type: ref
:text-align: center

Distances

:::

:::{grid-item-card}
:link: /examples/mlflow.ipynb
:link-type: ref
:text-align: center

MLflow

:::

::::
